@@ -824,8 +824,11 @@ def run(argv, dry_run=None):
     diffoscope = parsed_args.diffoscope
     if parsed_args.no_diffoscope:
         diffoscope_args = None
-    else:
+    elif shutil.which('diffoscope'):
         diffoscope_args = [diffoscope] + diffoscope_args
+    else:
+        logger.warning("diffoscope not available, falling back to regular diff")
+        diffoscope_args = None
     control_build = parsed_args.control_build
 
     if not artifact_pattern:
